@@ -1,8 +1,7 @@
-/* Output the generated parsing program for bison,
-   Copyright (C) 1984, 1986, 1989, 1992 Free Software Foundation, Inc.
-   Modified (1992) from bison-1.19 by 
-		Wilfred J. Hansen (wjh+@cmu.edu) 
-		Andrew Consortium, Carnegie Mellon University
+/* Output the generated parsing program for bison, Copyright (C) 1984,
+   1986, 1989, 1992 Free Software Foundation, Inc.  Modified (1992)
+   from bison-1.19 by Wilfred J. Hansen (wjh+@cmu.edu) Andrew
+   Consortium, Carnegie Mellon University
 
 This file is part of Bison, the GNU Compiler Compiler.
 
@@ -164,7 +163,7 @@ int pack_vector();
 
 extern void berror();
 extern void fatals();
-extern char *intToString();
+extern char *int_to_string();
 extern void reader_output_yylsp();
 
 static int nvectors;
@@ -282,7 +281,7 @@ output()
     output_stos();
   output_rule_data();
   output_actions();
-  if ( ! noparserflag)
+  if (! noparserflag)
     output_parser();
   output_program();
 }
@@ -342,7 +341,7 @@ output_gram()
   /* With the ordinary parser, 
      yyprhs and yyrhs are needed only for yydebug. */
   /* With the noparser option, all tables are generated */
-  if ( ! semantic_parser  && ! noparserflag)
+  if (! semantic_parser  && ! noparserflag)
     fprintf(ftable, "\n#if YYDEBUG != 0");
 
   fprintf(ftable, "\nstatic const short yyprhs[] = {     0");
@@ -392,7 +391,7 @@ output_gram()
 
   fprintf(ftable, "\n};\n");
 
-  if ( ! semantic_parser  && ! noparserflag)
+  if (! semantic_parser  && ! noparserflag)
     fprintf(ftable, "\n#endif\n");
 }
 
@@ -464,7 +463,7 @@ output_rule_data()
       fprintf(ftable, "#define YYMAXUTOK %d\n\n", max_user_token_number);
     }
 
-  if ( ! toknumflag  && ! noparserflag)
+  if (! toknumflag  && ! noparserflag)
     fprintf(ftable, "\n#if YYDEBUG != 0\n\n");
 
   /* Output the table of symbol names.  */
@@ -530,7 +529,7 @@ output_rule_data()
     }
     fprintf(ftable, ", NULL\n};\n");	/* add a NULL entry to list of tokens */
 
-  if ( ! toknumflag  && ! noparserflag)
+  if (! toknumflag  && ! noparserflag)
     fprintf(ftable, "#endif\n\n");
 
   if (toknumflag) 
@@ -1193,7 +1192,7 @@ int vector;
 	{
 	  loc = j + from[k];
 	  if (loc > MAXTABLE)
-	    fatals("maximum table size (%s) exceeded", intToString(MAXTABLE));
+	    fatals("maximum table size (%s) exceeded", int_to_string(MAXTABLE));
 
 	  if (table[loc] != 0)
 	    ok = 0;
@@ -1409,7 +1408,7 @@ output_parser()
 	  }
 
       /* now write out the line... */
-      for ( ; c != '\n' && c != EOF; c = getc(fpars))
+      for (; c != '\n' && c != EOF; c = getc(fpars))
 	if (write_line)
 	  if (c == '$')
 	    {
