@@ -62,7 +62,7 @@ extern void output_headers();
 extern void output_trailers();
 extern void free_symtab();
 extern void open_extra_files();
-extern char *intToString();
+extern char *int_to_string();
 extern void fatal();
 extern void fatals();
 extern void warn();
@@ -284,11 +284,9 @@ read_declarations ()
 	    case EXPECT:
 	      parse_expect_decl();
 	      break;
-	
 	    case THONG:
 	      parse_thong_decl();
 	      break;
-	
 	    case LEFT:
 	      parse_assoc_decl(LEFT_ASSOC);
 	      break;
@@ -313,6 +311,9 @@ read_declarations ()
 	      pure_parser = 1;
 	      break;
 
+	    case NOOP:
+	      break;
+
 	    default:
 	      warns("unrecognized: %s", token_buffer);
 	      skip_to_char('%');
@@ -323,9 +324,7 @@ read_declarations ()
       else
 	{
 		char buff[100];
-		sprintf(buff, 
-			"unknown character: %c (\\%03o)", 
-			c, c);
+		sprintf(buff, "unknown character: %s", printable_version(c)); 
 		warn(buff);
 		skip_to_char('%');
 	}
@@ -374,7 +373,7 @@ copy_definition ()
 	  while (c != match)
 	    {
 	      if (c == EOF)
-		fatal("unterminated string at EOF");
+		fatal("unterminated string at end of file");
 	      if (c == '\n')
 		{
 		  warn("unterminated string");
@@ -389,7 +388,7 @@ copy_definition ()
 		{
 		  c = getc(finput);
 		  if (c == EOF)
-		    fatal("unterminated string at EOF");
+		    fatal("unterminated string at end of file");
 		  putc(c, fattrs);
 		  if (c == '\n')
 		    lineno++;
@@ -480,51 +479,70 @@ parse_token_decl (what_is, what_is_not)
      int what_is, what_is_not;
 {
   register int token = 0;
-  register int prev;
   register char *typename = 0;
+  register struct bucket *symbol = NULL;  /* pts to symbol being defined */
   int k;
 
   for (;;)
     {
       if(ungetc(skip_white_space(), finput) == '%')
 	return;
-      prev = token;
       token = lex();
       if (token == COMMA)
-	continue;
+	{
+	  symbol = NULL;
+	  continue;
+	}
       if (token == TYPENAME)
 	{
 	  k = strlen(token_buffer);
 	  typename = NEW2(k + 1, char);
 	  strcpy(typename, token_buffer);
 	  value_components_used = 1;
+	  symbol = NULL;
+	}
+      else if (token == IDENTIFIER && *symval->tag == '\"'
+		&& symbol) 
+	{
+	  translations = 1;
+	  symval->class = STOKEN;
+	  symval->type_name = typename;
+	  symval->user_token_number = symbol->user_token_number;
+	  symbol->user_token_number = SALIAS;
+
+	  symval->alias = symbol;	
+	  symbol->alias = symval;	
+	  symbol = NULL;
+
+ 	  nsyms--;   /* symbol and symval combined are only one symbol */
 	}
       else if (token == IDENTIFIER)
 	{
 	  int oldclass = symval->class;
+	  symbol = symval;
 
-	  if (symval->class == what_is_not)
-	    warns("symbol %s redefined", symval->tag);
-	  symval->class = what_is;
+	  if (symbol->class == what_is_not)
+	    warns("symbol %s redefined", symbol->tag);
+	  symbol->class = what_is;
 	  if (what_is == SNTERM && oldclass != SNTERM)
-	    symval->value = nvars++;
+	    symbol->value = nvars++;
 
 	  if (typename)
 	    {
-	      if (symval->type_name == NULL)
-		symval->type_name = typename;
-	      else if (strcmp(typename, symval->type_name) != 0)
-		warns("type redeclaration for %s", symval->tag);
+	      if (symbol->type_name == NULL)
+		symbol->type_name = typename;
+	      else if (strcmp(typename, symbol->type_name) != 0)
+		warns("type redeclaration for %s", symbol->tag);
 	    }
 	}
-      else if (prev == IDENTIFIER && token == NUMBER)
+      else if (symbol && token == NUMBER)
         {
-	  symval->user_token_number = numval;
+	  symbol->user_token_number = numval;
 	  translations = 1;
         }
       else
 	{
-	  warnss("'%s' is invalid in %s",
+	  warnss("`%s' is invalid in %s",
 		token_buffer, 
 		(what_is == STOKEN) ? "%token" : "%nterm");
 	  skip_to_char('%');
@@ -541,9 +559,9 @@ parse_token_decl (what_is, what_is_not)
 
  Two symbols are entered in the table, one for the token symbol and
  one for the literal.  Both are given the <type>, if any, from the declaration.
- The user_token_number of the first is STHONG and any user_token_number from
- the declaration is stored in the second.  The two symbols are linked
- via pointers in their token_buddy fields.
+ The ->user_token_number of the first is SALIAS and the ->user_token_number
+ of the second is set to the number, if any, from the declaration.
+ The two symbols are linked via pointers in their ->alias fields.
  
  during output_defines_table, the symbol is reported
  thereafter, only the literal string is retained
@@ -579,7 +597,7 @@ parse_thong_decl ()
 	  }
 	symval->class = STOKEN;
 	symval->type_name = typename;
-	symval->user_token_number = STHONG;
+	symval->user_token_number = SALIAS;
 	symbol = symval;
 
 	token = lex();	/* get number or literal string */
@@ -603,14 +621,13 @@ parse_thong_decl ()
 	symval->type_name = typename;
 	symval->user_token_number = usrtoknum;
 
-	symval->thong_buddy = symbol;	
-	symbol->thong_buddy = symval;	
+	symval->alias = symbol;	
+	symbol->alias = symval;	
 
- 	nsyms--;   /* thong and buddy combined are only one symbol */
+ 	nsyms--;   /* symbol and symval combined are only one symbol */
 }
 
 
-
 /* parse what comes after %start */
 
 void
@@ -673,7 +690,7 @@ parse_type_decl ()
 	  break;
 
 	default:
-	  warns("invalid %%type declaration due to item: %s", token_buffer);
+	  warns("invalid %%type declaration due to item: `%s'", token_buffer);
 	  skip_to_char('%');
 	}
     }
@@ -740,7 +757,7 @@ int assoc;
             }
           else	  
             {
-	      warns("invalid text (%s).  Number should be after identifier.", 
+	      warns("invalid text (%s) - number should be after identifier", 
 			token_buffer);
 	      skip_to_char('%');
             }
@@ -832,7 +849,7 @@ parse_union_decl()
 			}
 		    }
 		  if (c == EOF)
-		    fatal("unterminated comment at EOF");
+		    fatal("unterminated comment at end of file");
 
 		  if (!cplus_comment && c == '*')
 		    {
@@ -902,7 +919,7 @@ parse_expect_decl()
   ungetc (c, finput);
 
   if (count <= 0 || count > 10)
-	warn("funny integer after %expect");
+	warn("argument of %expect is not an integer");
   expected_conflicts = atoi (buffer);
 }
 
@@ -997,7 +1014,7 @@ int stack_offset;
 	    count--;
 	  else 
 	    {
-	      warn("unmatched right brace ('}')");
+	      warn("unmatched right brace (`}')");
 	      c = getc(finput);	/* skip it */
 	    }
           break;
@@ -1011,7 +1028,7 @@ int stack_offset;
 	  while (c != match)
 	    {
 	      if (c == EOF)
-		fatal("unterminated string at EOF");
+		fatal("unterminated string at end of file");
 	      if (c == '\n') 
 		{
 		  warn("unterminated string");
@@ -1108,7 +1125,7 @@ int stack_offset;
 	      if (type_name)
 		fprintf(fguard, ".%s", type_name);
 	      if(!type_name && typed)
-		warns("$$ of '%s' has no declared type.", rule->sym->tag);
+		warns("$$ of `%s' has no declared type", rule->sym->tag);
 	    }
 
 	  else if (isdigit(c) || c == '-')
@@ -1124,11 +1141,11 @@ int stack_offset;
 	      if (type_name)
 		fprintf(fguard, ".%s", type_name);
 	      if(!type_name && typed)
-		warnss("$%s of '%s' has no declared type.", intToString(n), rule->sym->tag);
+		warnss("$%s of `%s' has no declared type", int_to_string(n), rule->sym->tag);
 	      continue;
 	    }
 	  else
-	    warni("$%c is invalid", c);
+	    warni("$%s is invalid", printable_version(c));
 
 	  break;
 
@@ -1142,7 +1159,7 @@ int stack_offset;
 	    }
 	  else
 	    {
-	      warni("@%c is invalid", c);
+	      warni("@%s is invalid", printable_version(c));
 	      n = 1;
 	    }
 
@@ -1152,7 +1169,7 @@ int stack_offset;
 	  continue;
 
 	case EOF:
-	  fatal("unterminated %guard clause");
+	  fatal("unterminated %%guard clause");
 
 	default:
 	  putc(c, fguard);
@@ -1240,7 +1257,7 @@ int stack_offset;
 		      continue;
 		    }
 		  else if (c == EOF)
-		    fatal("unterminated string at EOF");
+		    fatal("unterminated string at end of file");
 
 		  putc(c, faction);
 
@@ -1330,7 +1347,7 @@ int stack_offset;
 		  if (type_name)
 		    fprintf(faction, ".%s", type_name);
 		  if(!type_name && typed)	
-		    warns("$$ of '%s' has no declared type.", rule->sym->tag);
+		    warns("$$ of `%s' has no declared type", rule->sym->tag);
 		}
 	      else if (isdigit(c) || c == '-')
 		{
@@ -1345,11 +1362,12 @@ int stack_offset;
 		  if (type_name)
 		    fprintf(faction, ".%s", type_name);
 		  if(!type_name && typed)	
-		    warnss("$%s of '%s' has no declared type.", intToString(n), rule->sym->tag);
+		    warnss("$%s of `%s' has no declared type", 
+				int_to_string(n), rule->sym->tag);
 		  continue;
 		}
 	      else
-		warni("$%c is invalid",c);
+		warni("$%s is invalid", printable_version(c));
 
 	      break;
 
@@ -1373,7 +1391,7 @@ int stack_offset;
 	      continue;
 
 	    case EOF:
-	      fatal("unmatched '{'");
+	      fatal("unmatched `{'");
 
 	    default:
 	      putc(c, faction);
@@ -1603,7 +1621,7 @@ readgram()
 	  if (t == GUARD)
 	    {
 	      if (! semantic_parser)
-		warn("%guard present but %semantic_parser not specified");
+		warn("%%guard present but %%semantic_parser not specified");
 
 	      copy_guard(crule, rulelength);
 	      t = lex();
@@ -1623,7 +1641,7 @@ readgram()
 	    {
 	      if (lhs->type_name == 0 || first_rhs->type_name == 0
 		  || strcmp(lhs->type_name,first_rhs->type_name))
-		warnss("type clash ('%s' '%s') on default action",
+		warnss("type clash (`%s' `%s') on default action",
 			lhs->type_name ? lhs->type_name : "",
 			first_rhs->type_name ? first_rhs->type_name : "");
 	    }
@@ -1682,7 +1700,7 @@ readgram()
 
   if (nsyms > MAXSHORT)
     fatals("too many symbols (tokens plus nonterminals); maximum %s",
-	   intToString(MAXSHORT));
+	   int_to_string(MAXSHORT));
   if (nrules == 0)
     fatal("no rules in the input grammar");
 
@@ -1806,36 +1824,36 @@ packsymbols()
 	{
 	  bp->value += ntokens;
 	}
-      else if (bp->thong_buddy)
+      else if (bp->alias)
 	{
-		/* this symbol and its thong_buddy are a single thong defn.
+		/* this symbol and its alias are a single token defn.
 		  allocate a tokno, and assign to both
 		  check agreement of ->prec and ->assoc fields 
 			and make both the same
 		*/
 		if (bp->value == 0)
-			bp->value = bp->thong_buddy->value = tokno++;
+			bp->value = bp->alias->value = tokno++;
 
-		if (bp->prec != bp->thong_buddy->prec) {
-			if (bp->prec != 0 && bp->thong_buddy->prec != 0
-					&& bp->user_token_number == STHONG)
+		if (bp->prec != bp->alias->prec) {
+			if (bp->prec != 0 && bp->alias->prec != 0
+					&& bp->user_token_number == SALIAS)
 				warnss("conflicting precedences for %s and %s",
-					bp->tag, bp->thong_buddy->tag);
-			if (bp->prec != 0) bp->thong_buddy->prec = bp->prec;
-			else bp->prec = bp->thong_buddy->prec;
+					bp->tag, bp->alias->tag);
+			if (bp->prec != 0) bp->alias->prec = bp->prec;
+			else bp->prec = bp->alias->prec;
 		}
 
-		if (bp->assoc != bp->thong_buddy->assoc) {
-			if (bp->assoc != 0 && bp->thong_buddy->assoc != 0
-					&& bp->user_token_number == STHONG)
+		if (bp->assoc != bp->alias->assoc) {
+			if (bp->assoc != 0 && bp->alias->assoc != 0
+					&& bp->user_token_number == SALIAS)
 				warnss("conflicting assoc values for %s and %s",
-					bp->tag, bp->thong_buddy->tag);
-			if (bp->assoc != 0) bp->thong_buddy->assoc = bp->assoc;
-			else bp->assoc = bp->thong_buddy->assoc;
+					bp->tag, bp->alias->tag);
+			if (bp->assoc != 0) bp->alias->assoc = bp->assoc;
+			else bp->assoc = bp->alias->assoc;
 		}
 
-		if (bp->user_token_number == STHONG)
-			continue;  /* do not do processing below for STHONGs */
+		if (bp->user_token_number == SALIAS)
+			continue;  /* do not do processing below for SALIASs */
 
  	}
       else  /* bp->class == STOKEN */
@@ -1873,19 +1891,19 @@ packsymbols()
       for (bp = firstsymbol; bp; bp = bp->next)
         {
           if (bp->value >= ntokens) continue;		  /* non-terminal */
-          if (bp->user_token_number == STHONG) continue;  /* thong symbol */
-	  if (token_translations[bp->user_token_number] != 2)
-	    warnsss( "tokens %s and %s both assigned number %s",
+          if (bp->user_token_number == SALIAS) continue;  
+          if (token_translations[bp->user_token_number] != 2)
+	    warnsss("tokens %s and %s both assigned number %s",
 			      tags[token_translations[bp->user_token_number]],
 			      bp->tag,
-			      intToString(bp->user_token_number));
-	  token_translations[bp->user_token_number] = bp->value;
-	}
+			      int_to_string(bp->user_token_number));
+          token_translations[bp->user_token_number] = bp->value;
+        }
     }
 
   error_token_number = errtoken->value;
 
-  if ( ! noparserflag)
+  if (! noparserflag)
     output_token_defines(ftable);
 
   if (startval->class == SUNKNOWN)
@@ -1939,14 +1957,14 @@ FILE *file;
       symbol = bp->tag;				/* get symbol */
 
       if (bp->value >= ntokens) continue;
-      if (bp->user_token_number == STHONG) continue;
+      if (bp->user_token_number == SALIAS) continue;
       if ('\'' == *symbol) continue;	/* skip literal character */
       if (bp == errtoken) continue; 	/* skip error token */
       if ('\"' == *symbol) 
 	{
-		/* use literal string only if given a symbol via %thong */
-		if (bp->thong_buddy)
-			symbol = bp->thong_buddy->tag;
+		/* use literal string only if given a symbol with an alias */
+		if (bp->alias)
+			symbol = bp->alias->tag;
 		else
 			continue;
 	}
